﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using FarseerGames.FarseerPhysics;
using Labyrinth_Shooter.Interface;

namespace Labyrinth_Shooter
{
    class GameScreen
    {
        protected List<LogicalEntity> _entities = new List<LogicalEntity>();

        public InputManager Input
        {
            get { return _owner.Owner.InputManager; }
        }

        bool _update = true;
        public bool isUpdate
        {
            get { return _update; }
        }

        bool _draw = true;
        public bool isDraw
        {
            get { return _draw; }
        }

        ScreenManager _owner;
        public ScreenManager Owner
        {
            get { return _owner; }
        }


        public virtual void Init(ScreenManager owner)
        {
            _owner = owner;
        }

        public void AddEntity(LogicalEntity entity)
        {
            entity.Init(this);
            _entities.Add(entity);
        }

        public void RemoveEntity(LogicalEntity entity)
        {
            _entities.Remove(entity);
        }

        public virtual void Update(GameTime gameTime)
        {
            List<LogicalEntity> entitiesToUpdate = new List<LogicalEntity>();

            foreach (LogicalEntity entity in _entities)
            {
                if (entity.isUpdate)
                {
                    entitiesToUpdate.Add(entity);
                }
            }

            foreach (LogicalEntity entity in entitiesToUpdate)
            {
                entity.Update(gameTime);
            }
        }

        public virtual void Draw(SpriteBatch spriteBatch)
        {
            List<DrawableEntity> entitiesToDraw = new List<DrawableEntity>();

            foreach (DrawableEntity entity in _entities)
            {
                if (entity.isDraw)
                {
                    entitiesToDraw.Add(entity);
                }
            }

            foreach (DrawableEntity entity in entitiesToDraw)
            {
                entity.Draw(spriteBatch);
            }
        }
    }
}
