﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using FarseerGames.FarseerPhysics;
using Microsoft.Xna.Framework.Graphics;
using FarseerGames.FarseerPhysics.Dynamics;
using FarseerGames.FarseerPhysics.Collisions;
using FarseerGames.FarseerPhysics.Factories;
using Microsoft.Xna.Framework.Input;

namespace Labyrinth_Shooter.Entities
{
    class Player : DrawablePhysicsEntity
    {
        const float PLAYER_SPEED = 300.0f;
        const int PLAYER_SIZE = 32;

        public override Vector2 Position
        {
            get
            {
                return _body.Position;
            }
        }

        Texture2D _texture;

        Body _body;
        Geom _geometry;

        PlayerIndex playerIndex;

        public Player(Vector2 start, PlayerIndex index)
        {
            _position = start;
            playerIndex = index;
        }

        public override void Init(GameScreen owner)
        {
            _texture = owner.Owner.Owner.Content.Load<Texture2D>("Textures/Player_32");

            base.Init(owner);
        }

        public override void InitPhysics(PhysicsSimulator physicsSimulator)
        {
            _body = BodyFactory.Instance.CreateCircleBody(physicsSimulator, 30, 1);
            _body.Position = _position;
            _body.LinearDragCoefficient = 6.0f;
            _body.MomentOfInertia = float.MaxValue;
            _geometry = GeomFactory.Instance.CreateEllipseGeom(physicsSimulator, _body, PLAYER_SIZE / 2, PLAYER_SIZE / 2, 16);
        }

        public override void Draw(SpriteBatch spriteBatch)
        {
            spriteBatch.Draw(_texture, Position, null, Color.White, 0.0f, Vector2.One * (PLAYER_SIZE / 2), 1.0f, SpriteEffects.None, 0.9f);
        }

        public override void Update(GameTime gameTime)
        {
            Vector2 force = Vector2.Zero;

            if (playerIndex == PlayerIndex.One)
            {
                if (Owner.Input.isKeyDown(Keys.W)) { force.Y -= 1; }
                if (Owner.Input.isKeyDown(Keys.A)) { force.X -= 1; }
                if (Owner.Input.isKeyDown(Keys.S)) { force.Y += 1; }
                if (Owner.Input.isKeyDown(Keys.D)) { force.X += 1; }
            }
            else
            {
                if (Owner.Input.isKeyDown(Keys.Up)) { force.Y -= 1; }
                if (Owner.Input.isKeyDown(Keys.Left)) { force.X -= 1; }
                if (Owner.Input.isKeyDown(Keys.Down)) { force.Y += 1; }
                if (Owner.Input.isKeyDown(Keys.Right)) { force.X += 1; }
            }



            if (force.Length() > 0) {
                force.Normalize();
            }

            force = force * PLAYER_SPEED;
            _body.ApplyForce(force);

            _body.Rotation += 0.01f;
        }
    }
}
