﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
using FarseerGames.FarseerPhysics;
using FarseerGames.FarseerPhysics.Factories;
using FarseerGames.FarseerPhysics.Dynamics;
using FarseerGames.FarseerPhysics.Collisions;

namespace Labyrinth_Shooter.Entities
{
    class Tile : DrawablePhysicsEntity
    {
        public override Vector2 Position
        {
            get
            {
                if (_solid)
                    return _body.Position;
                else
                    return _position;
            }
        }

        const int TILE_SIZE = 32;

        Texture2D _texture;
        string _textureName;
        bool _solid = false;

        Body _body;
        Geom _geometry;

        public Tile(string texture, int x, int y, bool solid)
        {
            _textureName = texture;
            _position = new Vector2(TILE_SIZE * x, TILE_SIZE * y) + (Vector2.One * (TILE_SIZE / 2));
            _solid = solid;
        }

        public override void Init(GameScreen owner)
        {
            base.Init(owner);

            _update = false;

            _texture = owner.Owner.Owner.Content.Load<Texture2D>("Textures/" + _textureName);
        }

        public override void Draw(SpriteBatch spriteBatch)
        {
            spriteBatch.Draw(_texture, Position, null, Color.White, 0.0f, Vector2.One * (TILE_SIZE / 2), 1.0f, SpriteEffects.None, 1.0f);
        }

        public override void Update(GameTime gameTime)
        {
        }

        public override void InitPhysics(PhysicsSimulator physicsSimulator)
        {
            if (_solid)
            {
                _body = BodyFactory.Instance.CreateRectangleBody(physicsSimulator, TILE_SIZE, TILE_SIZE, 1);
                _body.IgnoreGravity = true;
                _body.IsStatic = true;
                _body.Position = _position;
                _geometry = GeomFactory.Instance.CreateRectangleGeom(physicsSimulator, _body, TILE_SIZE, TILE_SIZE);
            }
        }
    }
}
