﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Labyrinth_Shooter.Entities;
using FarseerGames.FarseerPhysics;
using DemoBaseXNA;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Labyrinth_Shooter.Base.Screens;

namespace Labyrinth_Shooter.Screens
{
    class PlayScreen : PhysicsScreen
    {
        List<Viewport> _viewports;
        List<Camera> _cameras;

        int _numPlayers;

        public PlayScreen(int numPlayers)
        {
            _numPlayers = numPlayers;
            _viewports = new List<Viewport>(_numPlayers);
            _cameras = new List<Camera>(_numPlayers);
        }

        public override void Init(ScreenManager owner)
        {
            base.Init(owner);

            for(int i = 0; i < _numPlayers; i++)
            {
                Player player = new Player(new Vector2(100.0f, i * 100.0f), (PlayerIndex)i);
                _cameras.Add(new Camera(player));
                AddEntity(player);
            }

            Viewport defaultViewport = owner.Owner.DefaultViewport;
            switch (_numPlayers)
            {
                case 1:
                    //Player 1
                    _viewports.Add(defaultViewport);
                    break;
                case 2:
                    _viewports.Add(new Viewport(0, 0, defaultViewport.Width, defaultViewport.Height / 2));
                    _viewports.Add(new Viewport(0, defaultViewport.Height / 2, defaultViewport.Width, defaultViewport.Height / 2));
                    break;
                case 3:
                    _viewports.Add(new Viewport(0, 0, defaultViewport.Width / 2, defaultViewport.Height / 2));
                    _viewports.Add(new Viewport(defaultViewport.Width / 2, 0, defaultViewport.Width / 2, defaultViewport.Height / 2));
                    _viewports.Add(new Viewport(0, defaultViewport.Height / 2, defaultViewport.Width / 2, defaultViewport.Height / 2));
                    break;
                case 4:
                    _viewports.Add(new Viewport(0, 0, defaultViewport.Width / 2, defaultViewport.Height / 2));
                    _viewports.Add(new Viewport(defaultViewport.Width / 2, 0, defaultViewport.Width / 2, defaultViewport.Height / 2));
                    _viewports.Add(new Viewport(0, defaultViewport.Height / 2, defaultViewport.Width / 2, defaultViewport.Height / 2));
                    _viewports.Add(new Viewport(defaultViewport.Width / 2, defaultViewport.Height / 2, defaultViewport.Width / 2, defaultViewport.Height / 2));
                    break;
                default:
                    break;
            }

            /*projectionMatrix = Matrix.CreatePerspectiveFieldOfView(
                MathHelper.PiOver4, 4.0f / 3.0f, 1.0f, 10000f);
            halfprojectionMatrix = Matrix.CreatePerspectiveFieldOfView(
                MathHelper.PiOver4, 2.0f / 3.0f, 1.0f, 10000f);*/

            AddEntity(new Tile("Metal01_32", 0, 0, true));
            AddEntity(new Tile("Metal01_32", 1, 0, true));
            AddEntity(new Tile("Metal01_32", 2, 0, true));
            AddEntity(new Tile("Metal01_32", 3, 0, true));
            AddEntity(new Tile("Metal01_32", 0, 2, false));
            AddEntity(new Tile("Metal01_32", 2, 2, false));
            AddEntity(new Tile("Metal01_32", 4, 2, false));
            AddEntity(new Tile("Metal01_32", 6, 2, false));
        }

        public override void  Update(GameTime gameTime)
        {
 	         base.Update(gameTime);
        }

        public override void Draw(SpriteBatch spriteBatch)
        {
            for(int i = 0; i < _viewports.Count; i++)
            {
                Owner.Owner.GraphicsDevice.Viewport = _viewports[i];
                spriteBatch.Begin(SpriteSortMode.BackToFront, null, null, null, null, null, _cameras[i].getTranslation() * Matrix.CreateTranslation(_viewports[i].Width / 2, _viewports[i].Height / 2, 0.0f));
                base.Draw(spriteBatch);
                spriteBatch.End();

            }    
        }
    }
}
