#include "StdAfx.h"
#include "EngineCore.h"

namespace Zeta
{
	namespace GameEngine
	{
		EngineCore::EngineCore(HWND hWnd)
		{
			D3DInterface = Direct3DCreate9(D3D_SDK_VERSION);    // create the Direct3D interface

			D3DPRESENT_PARAMETERS D3DPresentParameters;    // create a struct to hold various device information

			ZeroMemory(&D3DPresentParameters, sizeof(D3DPresentParameters));    // clear out the struct for use
		#ifdef FULLSCREEN
			D3DPresentParameters.Windowed = FALSE;
		#else
			D3DPresentParameters.Windowed = TRUE;    // program windowed, not fullscreen
		#endif
			D3DPresentParameters.SwapEffect = D3DSWAPEFFECT_DISCARD;    // discard old frames
			D3DPresentParameters.hDeviceWindow = hWnd;    // set the window to be used by Direct3D
		#ifdef FULLSCREEN
			d3dpp.BackBufferFormat = D3DFMT_X8R8G8B8;    // set the back buffer format to 32-bit
			d3dpp.BackBufferWidth = SCREEN_WIDTH;    // set the width of the buffer
			d3dpp.BackBufferHeight = SCREEN_HEIGHT;    // set the height of the buffer
		#endif


			// create a device class using this information and information from the d3dpp stuct
			D3DInterface->CreateDevice(D3DADAPTER_DEFAULT,
							  D3DDEVTYPE_HAL,
							  hWnd,
							  D3DCREATE_SOFTWARE_VERTEXPROCESSING,
							  &D3DPresentParameters,
							  &D3DDevice);
		}

		EngineCore::~EngineCore(void)
		{
			D3DDevice->Release();    // close and release the 3D device
			D3DInterface->Release();    // close and release Direct3D
		}

		BOOL EngineCore::Render(void)
		{
			// clear the window to a deep blue
			D3DDevice->Clear(0, NULL, D3DCLEAR_TARGET, D3DCOLOR_XRGB(0, 40, 100), 1.0f, 0);
			D3DDevice->BeginScene();    // begins the 3D scene

			// do 3D rendering on the back buffer here
			D3DDevice->EndScene();    // ends the 3D scene
			D3DDevice->Present(NULL, NULL, NULL, NULL);    // displays the created frame

			return TRUE;
		}

		BOOL EngineCore::Process(void)
		{
			return Render();
		}
	}
}