#include "StdAfx.h"
#include "Window.h"

namespace Zeta
{
	namespace Windows
	{
		Window::Window()
		{
		}

		Window::~Window(void)
		{
		}

		BOOL Window::Show(int nCmdShow)
		{
			// display the window on the screen
			return ShowWindow(hWnd, nCmdShow);
		}

		HWND Window::getWindow(void)
		{
			return hWnd;
		}

		// The helper window procedure
		// It is called by Windows, and thus it's a non-member function
		// This message handler will only be called after successful SetWindowLong call
		// We can assume that pointer returned by GetWindowLong is valid
		// It will route messages to our member message handler
		LRESULT CALLBACK Window::WindowProcSwitch(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
		{
			// Get a window pointer associated with this window
			Window *window = (Window *) GetWindowLong(hWnd, GWL_USERDATA);
			// It should be valid, assert so
			_ASSERT(window);
			// Redirect messages to the window procedure of the associated window
			return window->WindowProc(hWnd, message, wParam, lParam);
		}

		// The helper window procedure
		// It is called by Windows, and thus it's a non-member function
		// It will provide default handling for messages until WM_NCCREATE comes around,
		// in which case it will set per-window this pointer to whatever was passed in CREATESTRUCT
		// and reset the window's message handler to WndProc2
		LRESULT CALLBACK Window::WindowProcInit(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
		{
			// If the message is WM_NCCREATE, associate Window pointer with this window
			// Note: WM_NCCREATE is not the first message that this WndProc will process
			if (message == WM_NCCREATE) {
				LPCREATESTRUCT cs = (LPCREATESTRUCT) lParam;
				// Set associated this pointer
				SetWindowLong(hWnd, GWL_USERDATA, (long) cs->lpCreateParams);
				// Reset the window message handler
				SetWindowLong(hWnd, GWL_WNDPROC, (long) Window::WindowProcSwitch);
				// Dispatch WM_NCCREATE to the member message handler
				return Window::WindowProcSwitch(hWnd, message, wParam, lParam);
			} else {
				// Use default handling; the window is not associated yet
				return DefWindowProc(hWnd, message, wParam, lParam);
			}
		}
	}
}